
API
===

.. currentmodule:: footings

The footings library is made up of three sub-libraries -

- core
- tools
- doctolls


core
----
.. automodule:: footings
   :exclude-members:

.. autosummary::
   :nosignatures:
   :toctree: generated

   Footing
   Footing.audit
   Footing.run
   Footing.visualize
   model
   step
   define_parameter
   define_modifier
   define_meta
   define_placeholder
   define_asset
   dispatch_function

|


tools
-----

.. currentmodule:: footings.tools

.. automodule:: footings.tools
   :exclude-members:

.. autosummary::
   :nosignatures:
   :toctree: generated

   create_frame
   create_frame_from_record
   expand_frame_per_record
   calculate_age
   assert_footings_audit_xlsx_equal
   load_footings_audit_xlsx

|


doctools
--------

.. currentmodule:: footings.doctools

.. automodule:: footings.doctools
   :exclude-members:
